@@ -1,5 +1,5 @@
 """
-Cycle Pre Checks Site
+Pre Checks Site
 
 Some Cycle models need a full version of the linked [Site](https://hestia.earth/schema/Site) to run.
 This model will fetch the complete version of the [Site](https://hestia.earth/schema/Site) and include it.
