@@ -15,7 +15,7 @@ from . import MODEL
 
 REQUIREMENTS = {
     "ImpactAssessment": {
-        "product": {"@type": "Term"},
+        "product": {"@type": "Product", "term": {"@type": "Term"}},
         "cycle": {
             "@type": "Cycle",
             "products": [{
@@ -39,7 +39,8 @@ MODEL_KEY = 'emissions'
 
 def _indicator(product: dict):
     def run(emission: dict):
-        value = convert_value_from_cycle(product, list_sum(emission.get('value', [0])))
+        term_id = emission.get('term', {}).get('@id')
+        value = convert_value_from_cycle(product, list_sum(emission.get('value', [0])), model=MODEL, term_id=term_id)
 
         indicator = _new_indicator(emission.get('term', {}))
         indicator['value'] = value
@@ -68,7 +69,7 @@ def _should_run_emission(impact_assessment: dict):
 
         logRequirements(impact_assessment, model=MODEL, term=term_id,
                         has_value=has_value,
-                        not_deleted=not_deleted)
+                        emission_included_in_models=not_deleted)
 
         should_run = all([has_value, not_deleted])
         logShouldRun(impact_assessment, MODEL, term_id, should_run)
