@@ -1,4 +1,4 @@
-from hestia_earth.schema import EmissionMethodTier, EmissionStatsDefinition, TermTermType
+from hestia_earth.schema import EmissionMethodTier, TermTermType
 
 from hestia_earth.models.log import debugValues, logRequirements, logShouldRun
 from hestia_earth.models.utils.constant import Units, get_atomic_conversion
@@ -29,8 +29,7 @@ REQUIREMENTS = {
 RETURNS = {
     "Emission": [{
         "value": "",
-        "methodTier": "tier 1",
-        "statsDefinition": "modelled"
+        "methodTier": "tier 1"
     }]
 }
 TERM_ID = 'n2OToAirExcretaIndirect'
@@ -44,7 +43,6 @@ def _emission(value: float):
     emission = _new_emission(TERM_ID, MODEL)
     emission['value'] = [value]
     emission['methodTier'] = TIER
-    emission['statsDefinition'] = EmissionStatsDefinition.MODELLED.value
     return emission
 
 
@@ -68,7 +66,7 @@ def _should_run(cycle: dict):
 
     logRequirements(cycle, model=MODEL, term=TERM_ID,
                     N_total=N_total,
-                    term_type_complete=term_type_complete)
+                    term_type_excreta_complete=term_type_complete)
 
     should_run = any([N_total, term_type_complete])
     logShouldRun(cycle, MODEL, TERM_ID, should_run, methodTier=TIER)
