@@ -5,21 +5,24 @@ This model estimates the energetic requirements of ruminants and can be used to
 Source:
 [IPCC 2019, Vol.4, Chapter 10](https://www.ipcc-nggip.iges.or.jp/public/2019rf/pdf/4_Volume4/19R_V4_Ch10_Livestock.pdf).
 """
-from hestia_earth.schema import InputStatsDefinition, TermTermType, AnimalReferencePeriod
+from hestia_earth.schema import TermTermType, AnimalReferencePeriod
+from hestia_earth.utils.api import download_hestia
 from hestia_earth.utils.lookup import download_lookup, get_table_value, column_name, extract_grouped_data
 from hestia_earth.utils.model import filter_list_term_type
-from hestia_earth.utils.tools import list_sum, safe_parse_float
+from hestia_earth.utils.tools import list_sum, safe_parse_float, non_empty_list
 
 from hestia_earth.models.log import debugValues, logRequirements, logShouldRun
-from hestia_earth.models.utils.input import _new_input
-from hestia_earth.models.utils.completeness import _is_term_type_incomplete
-from hestia_earth.models.utils.term import get_lookup_value, get_milkYield_terms, get_wool_terms
-from hestia_earth.models.utils.property import get_node_property, get_node_property_value, _node_property_value
+from hestia_earth.models.utils.input import _new_input, get_feed_inputs
+from hestia_earth.models.utils.completeness import _is_term_type_complete, _is_term_type_incomplete
+from hestia_earth.models.utils.term import get_lookup_value, get_wool_terms
+from hestia_earth.models.utils.property import get_node_property, get_node_property_value, node_property_lookup_value
+from .utils import get_milkYield_practice
 from . import MODEL
 
 REQUIREMENTS = {
     "Cycle": {
-        "completeness.animalFeed": "False",
+        "completeness.animalFeed": "True",
+        "completeness.grazedForage": "False",
         "site": {
             "@type": "Site",
             "siteType": "permanent pasture"
@@ -30,7 +33,7 @@ REQUIREMENTS = {
             "term.@id": "pastureGrass",
             "key": {
                 "@type": "Term",
-                "term.termType": ["crop", "forage"]
+                "term.termType": "landCover"
             }
         }],
         "animals": [{
@@ -56,6 +59,18 @@ REQUIREMENTS = {
                         "animalsPerBirth"
                     ]
                 }],
+                "inputs": [{
+                    "@type": "Input",
+                    "term.units": "kg",
+                    "value": "> 0",
+                    "optional": {
+                        "properties": [{
+                            "@type": "Property",
+                            "value": "",
+                            "term.@id": ["neutralDetergentFibreContent", "energyContentHigherHeatingValue"]
+                        }]
+                    }
+                }],
                 "practices": [{
                     "@type": "Practice",
                     "value": "",
@@ -69,6 +84,19 @@ REQUIREMENTS = {
             }
         }],
         "optional": {
+            "inputs": [{
+                "@type": "Input",
+                "term.units": "kg",
+                "value": "> 0",
+                "isAnimalFeed": "True",
+                "optional": {
+                    "properties": [{
+                        "@type": "Property",
+                        "value": "",
+                        "term.@id": ["neutralDetergentFibreContent", "energyContentHigherHeatingValue"]
+                    }]
+                }
+            }],
             "products": [{
                 "@type": "Product",
                 "value": "",
@@ -93,30 +121,29 @@ LOOKUPS = {
     "crop-property": ["energyDigestibilityRuminants", "energyContentHigherHeatingValue"],
     "crop": "grazedPastureGrassInputId",
     "forage-property": ["energyDigestibilityRuminants", "energyContentHigherHeatingValue"],
-    "forage": "grazedPastureGrassInputId"
+    "landCover": "grazedPastureGrassInputId"
 }
 RETURNS = {
     "Input": [{
         "term.termType": ["crop", "forage"],
-        "value": "",
-        "statsDefinition": "modelled"
+        "value": ""
     }]
 }
 MODEL_KEY = 'pastureGrass'
-MODEL_LOG = '/'.join([MODEL, MODEL_KEY])
 KEY_TERM_TYPES = [
-    TermTermType.CROP.value,
-    TermTermType.FORAGE.value
+    TermTermType.LANDCOVER.value
 ]
 
 
 def _input(term_id: str, value: float):
     node = _new_input(term_id, MODEL)
     node['value'] = [value]
-    node['statsDefinition'] = InputStatsDefinition.MODELLED.value
     return node
 
 
+def _practice_input_id(practice: dict): return get_lookup_value(practice.get('key', {}), 'grazedPastureGrassInputId')
+
+
 def _get_grouping(animal: dict):
     term = animal.get('term', {})
     return get_lookup_value(term, 'ipcc2019AnimalTypeGrouping')
@@ -129,17 +156,12 @@ def _get_activityCoefficient(cycle: dict, animal: dict, system: dict):
     lookup = download_lookup('system-liveAnimal-activityCoefficient-ipcc2019.csv')
     activityCoefficient = safe_parse_float(get_table_value(lookup, 'termid', system_id, column_name(term_id)), 0)
 
-    debugValues(cycle, model=MODEL_LOG, term=term_id,
+    debugValues(cycle, model=MODEL, term=term_id,
                 activityCoefficient=activityCoefficient)
 
     return activityCoefficient
 
 
-def _get_milkYield_practice(animal: dict):
-    terms = get_milkYield_terms()
-    return next((p for p in animal.get('practices', []) if p.get('term', {}).get('@id') in terms), {})
-
-
 def _calculate_NEm(cycle: dict, animal: dict):
     term = animal.get('term', {})
     term_id = term.get('@id')
@@ -152,7 +174,7 @@ def _calculate_NEm(cycle: dict, animal: dict):
     cycleDuration = cycle.get('cycleDuration', 365)
     NEm = mjDayKgCfiNetEnergyMaintenance * pow(liveweightPerHead, 0.75) * animal_value * cycleDuration
 
-    debugValues(cycle, model=MODEL_LOG, term=term_id,
+    debugValues(cycle, model=MODEL, term=term_id,
                 mjDayKgCfiNetEnergyMaintenance=mjDayKgCfiNetEnergyMaintenance,
                 liveweightPerHead=liveweightPerHead,
                 NEm=NEm)
@@ -168,10 +190,10 @@ def _calculate_NEa_cattleAndBuffalo(cycle: dict, animal: dict, system: dict, NEm
 
     NEa = activityCoefficient * NEm
 
-    debugValues(cycle, model=MODEL_LOG, term=term_id,
+    debugValues(cycle, model=MODEL, term=term_id,
                 NEa=NEa)
 
-    return NEa
+    return term_id, NEa
 
 
 def _calculate_NEa_sheepAndGoat(cycle: dict, animal: dict, system: dict, _NEm: float):
@@ -185,11 +207,11 @@ def _calculate_NEa_sheepAndGoat(cycle: dict, animal: dict, system: dict, _NEm: f
     cycleDuration = cycle.get('cycleDuration', 365)
     NEa = activityCoefficient * liveweightPerHead * animal_value * cycleDuration
 
-    debugValues(cycle, model=MODEL_LOG, term=term_id,
+    debugValues(cycle, model=MODEL, term=term_id,
                 liveweightPerHead=liveweightPerHead,
                 NEa=NEa)
 
-    return NEa
+    return term_id, NEa
 
 
 _NEa_BY_GROUPING = {
@@ -200,33 +222,33 @@ _NEa_BY_GROUPING = {
 
 def _calculate_NEa(cycle: dict, animal: dict, system: dict, NEm: float):
     grouping = _get_grouping(animal)
-    return _NEa_BY_GROUPING[grouping](cycle, animal, system, NEm)
+    return _NEa_BY_GROUPING.get(grouping, lambda *args: None)(cycle, animal, system, NEm)
 
 
 def _calculate_NEl_cattleAndBuffalo(cycle: dict, animal: dict):
     term = animal.get('term', {})
     term_id = term.get('@id')
 
-    milkYieldPractice = _get_milkYield_practice(animal)
+    milkYieldPractice = get_milkYield_practice(animal)
     milkYield = list_sum(milkYieldPractice.get('value', []))
     fatContent = get_node_property(milkYieldPractice, 'fatContent').get('value', 0)
     animal_value = animal.get('value', 0)
     cycleDuration = cycle.get('cycleDuration', 365)
     NEl = milkYield * (1.47 + (0.4 * fatContent)) * animal_value * cycleDuration
 
-    debugValues(cycle, model=MODEL_LOG, term=term_id,
+    debugValues(cycle, model=MODEL, term=term_id,
                 milkYield=milkYield,
                 fatContent=fatContent,
                 NEl=NEl)
 
-    return NEl
+    return term_id, NEl
 
 
 def _calculate_NEl_sheepAndGoat(cycle: dict, animal: dict):
     term = animal.get('term', {})
     term_id = term.get('@id')
 
-    milkYieldPractice = _get_milkYield_practice(animal)
+    milkYieldPractice = get_milkYield_practice(animal)
     milkYield = list_sum(milkYieldPractice.get('value', []))
     EV_milk = safe_parse_float(get_lookup_value(milkYieldPractice.get('term', {}), 'mjKgEvMilkIpcc2019'), 0)
     fatContent = get_node_property(milkYieldPractice, 'fatContent').get('value', 0)
@@ -234,12 +256,12 @@ def _calculate_NEl_sheepAndGoat(cycle: dict, animal: dict):
     cycleDuration = cycle.get('cycleDuration', 365)
     NEl = milkYield * (EV_milk * fatContent/7) * animal_value * cycleDuration
 
-    debugValues(cycle, model=MODEL_LOG, term=term_id,
+    debugValues(cycle, model=MODEL, term=term_id,
                 milkYield=milkYield,
                 EV_milk=EV_milk,
                 NEl=NEl)
 
-    return NEl
+    return term_id, NEl
 
 
 _NEl_BY_GROUPING = {
@@ -250,7 +272,7 @@ _NEl_BY_GROUPING = {
 
 def _calculate_NEl(cycle: dict, animal: dict):
     grouping = _get_grouping(animal)
-    return _NEl_BY_GROUPING[grouping](cycle, animal)
+    return _NEl_BY_GROUPING.get(grouping, lambda *args: None)(cycle, animal)
 
 
 def _calculate_NEwork(cycle: dict, animal: dict, NEm: float):
@@ -260,11 +282,11 @@ def _calculate_NEwork(cycle: dict, animal: dict, NEm: float):
     hoursWorkedPerDay = get_node_property(animal, 'hoursWorkedPerDay').get('value', 0)
     NEwork = 0.1 * NEm * hoursWorkedPerDay
 
-    debugValues(cycle, model=MODEL_LOG, term=term_id,
+    debugValues(cycle, model=MODEL, term=term_id,
                 hoursWorkedPerDay=hoursWorkedPerDay,
                 NEwork=NEwork)
 
-    return NEwork
+    return term_id, NEwork
 
 
 def _get_pregnancy_ratio_per_birth(animal: dict, value: str):
@@ -295,12 +317,12 @@ def _calculate_NEp(cycle: dict, animal: dict, NEm: float):
     pregnancyRateTotal = get_node_property(animal, 'pregnancyRateTotal').get('value', 0)
     NEp = ratioCPregnancyNetEnergyPregnancy * pregnancyRateTotal/100 * NEm
 
-    debugValues(cycle, model=MODEL_LOG, term=term_id,
+    debugValues(cycle, model=MODEL, term=term_id,
                 ratioCPregnancyNetEnergyPregnancy=ratioCPregnancyNetEnergyPregnancy,
                 pregnancyRateTotal=pregnancyRateTotal,
                 NEp=NEp)
 
-    return NEp
+    return term_id, NEp
 
 
 def _calculate_NEg_cattleAndBuffalo(cycle: dict, animal: dict):
@@ -318,16 +340,18 @@ def _calculate_NEg_cattleAndBuffalo(cycle: dict, animal: dict):
     NEg = 22.02 * \
         pow(liveweightPerHead / (ratioCNetEnergyGrowthCattleBuffalo * weightAtMaturity), 0.75) * \
         pow(liveweightGain, 1.097) * \
-        animal_value * cycleDuration
+        animal_value * cycleDuration if all([
+            ratioCNetEnergyGrowthCattleBuffalo * weightAtMaturity > 0
+        ]) else 0
 
-    debugValues(cycle, model=MODEL_LOG, term=term_id,
+    debugValues(cycle, model=MODEL, term=term_id,
                 ratioCNetEnergyGrowthCattleBuffalo=ratioCNetEnergyGrowthCattleBuffalo,
                 liveweightPerHead=liveweightPerHead,
                 weightAtMaturity=weightAtMaturity,
                 liveweightGain=liveweightGain,
                 NEg=NEg)
 
-    return NEg
+    return term_id, NEg
 
 
 def _calculate_NEg_sheepAndGoat(cycle: dict, animal: dict):
@@ -344,14 +368,14 @@ def _calculate_NEg_sheepAndGoat(cycle: dict, animal: dict):
     cycleDuration = cycle.get('cycleDuration', 365)
     NEg = (BWf - BWi) * (MjKg_a + 0.5 * MjKg_b * (BWi + BWf)) / 365 * animal_value * cycleDuration
 
-    debugValues(cycle, model=MODEL_LOG, term=term_id,
+    debugValues(cycle, model=MODEL, term=term_id,
                 MjKg_a=MjKg_a,
                 MjKg_b=MjKg_b,
                 BWi=BWi,
                 BWf=BWf,
                 NEg=NEg)
 
-    return NEg
+    return term_id, NEg
 
 
 _NEg_BY_GROUPING = {
@@ -362,7 +386,7 @@ _NEg_BY_GROUPING = {
 
 def _calculate_NEg(cycle: dict, animal: dict):
     grouping = _get_grouping(animal)
-    return _NEg_BY_GROUPING[grouping](cycle, animal)
+    return _NEg_BY_GROUPING.get(grouping, lambda *args: None)(cycle, animal)
 
 
 def _calculate_NEwool(cycle: dict):
@@ -379,43 +403,40 @@ def _calculate_NEwool(cycle: dict):
 
 
 def _pastureGrass_key_property_value(practice: dict, column: dict):
-    term = practice.get('key', {})
-    term_id = get_lookup_value(term, 'grazedPastureGrassInputId')
+    term_id = _practice_input_id(practice)
+    term = download_hestia(term_id)
     term_type = term.get('termType')
     value = list_sum(practice.get('value', [0]))
-    lookup_value = _node_property_value({'@id': term_id, 'termType': term_type}, column)
+    lookup_value = node_property_lookup_value(MODEL, {'@id': term_id, 'termType': term_type}, column, default=0)
     return (lookup_value, value)
 
 
-def _calculate_meanDE(cycle: dict, practices: list):
+def _calculate_meanDE(practices: list):
     values = list(map(lambda p: _pastureGrass_key_property_value(p, 'energyDigestibilityRuminants'), practices))
     total_weight = sum([weight/100 for _value, weight in values])
     meanDE = sum([
-        value * weight/100 for value, weight in values
+        (value * weight/100 if all([value, weight]) else 0) for value, weight in values
     ]) / total_weight if total_weight > 0 else 0
 
-    debugValues(cycle, model=MODEL_LOG, term=MODEL_KEY,
-                meanDE=meanDE)
-
     return meanDE
 
 
-def _calculate_REM(meanDE: float):
-    return 1.123 - (4.092/1000 * meanDE) + (1.126/100000 * pow(meanDE, 2)) - (25.4/meanDE) if meanDE > 0 else 0
+def _calculate_REM(energy: float = 0):
+    return 1.123 - (4.092/1000 * energy) + (1.126/100000 * pow(energy, 2)) - (25.4/energy) if energy > 0 else 0
 
 
-def _calculate_REG(meanDE: float):
-    return 1.164 - (5.16/1000 * meanDE) + (1.308/100000 * pow(meanDE, 2)) - (37.4/meanDE) if meanDE > 0 else 0
+def _calculate_REG(energy: float = 0):
+    return 1.164 - (5.16/1000 * energy) + (1.308/100000 * pow(energy, 2)) - (37.4/energy) if energy > 0 else 0
 
 
 def _calculate_feed_meanDE(cycle: dict, input: dict):
     term_id = input.get('term', {}).get('@id')
 
-    energyContent = get_node_property_value(input, 'energyContentHigherHeatingValue')
-    energyDigestibility = get_node_property_value(input, 'energyDigestibilityRuminants')
-    meanDE = energyContent * (energyDigestibility/100)
+    energyContent = get_node_property_value(MODEL, input, 'energyContentHigherHeatingValue')
+    energyDigestibility = get_node_property_value(MODEL, input, 'energyDigestibilityRuminants')
+    meanDE = energyContent * energyDigestibility if all([energyContent, energyDigestibility]) else 0
 
-    debugValues(cycle, model=MODEL_LOG, term=term_id,
+    debugValues(cycle, model=MODEL, term=term_id,
                 energyContent=energyContent,
                 energyDigestibility=energyDigestibility,
                 meanDE=meanDE)
@@ -426,10 +447,10 @@ def _calculate_feed_meanDE(cycle: dict, input: dict):
 def _calculate_NEfeed_m(cycle: dict, input: dict, meanDE: float):
     term_id = input.get('term', {}).get('@id')
 
-    energyDigestibility = get_node_property_value(input, 'energyDigestibilityRuminants')
-    REm = _calculate_REM(energyDigestibility)
+    energyDigestibility = get_node_property_value(MODEL, input, 'energyDigestibilityRuminants', default=0)
+    REm = _calculate_REM(energyDigestibility * 100)
 
-    debugValues(cycle, model=MODEL_LOG, term=term_id,
+    debugValues(cycle, model=MODEL, term=term_id,
                 REm=REm)
 
     input_value = list_sum(input.get('value'))
@@ -439,10 +460,10 @@ def _calculate_NEfeed_m(cycle: dict, input: dict, meanDE: float):
 def _calculate_NEfeed_g(cycle: dict, input: dict, meanDE: float):
     term_id = input.get('term', {}).get('@id')
 
-    energyDigestibility = get_node_property_value(input, 'energyDigestibilityRuminants')
-    REg = _calculate_REG(energyDigestibility)
+    energyDigestibility = get_node_property_value(MODEL, input, 'energyDigestibilityRuminants', default=0)
+    REg = _calculate_REG(energyDigestibility * 100)
 
-    debugValues(cycle, model=MODEL_LOG, term=term_id,
+    debugValues(cycle, model=MODEL, term=term_id,
                 REg=REg)
 
     input_value = list_sum(input.get('value'))
@@ -450,10 +471,7 @@ def _calculate_NEfeed_g(cycle: dict, input: dict, meanDE: float):
 
 
 def _calculate_NEfeed(cycle: dict):
-    inputs = [i for i in cycle.get('inputs', []) if all([
-        len(i.get('value')) > 0,
-        i.get('isAnimalFeed', False) is True
-    ])]
+    inputs = get_feed_inputs(cycle)
     # calculate meanDE for each input first
     inputs = [(input, _calculate_feed_meanDE(cycle, input)) for input in inputs]
     NEfeed_m = sum([
@@ -466,6 +484,12 @@ def _calculate_NEfeed(cycle: dict):
     return (NEfeed_m, NEfeed_g)
 
 
+def _group_logs(values: list): return ';'.join([f"id:{term_id}_value:{value}" for term_id, value in values if term_id])
+
+
+def _sum_values(values): return sum([value for term_id, value in values])
+
+
 def _calculate_GE(cycle: dict, meanDE: float, system: dict):
     animals = [
         a for a in cycle.get('animals', []) if all([
@@ -476,12 +500,13 @@ def _calculate_GE(cycle: dict, meanDE: float, system: dict):
     # calculate NEm first and re-use in other places
     animals = [(animal, _calculate_NEm(cycle, animal)) for animal in animals]
 
-    NEm = sum([NEm for (_animal, NEm) in animals])
-    NEa = sum([_calculate_NEa(cycle, animal, system, NEm) for (animal, NEm) in animals])
-    NEl = sum([_calculate_NEl(cycle, animal) for (animal, _NEm) in animals])
-    NEwork = sum([_calculate_NEwork(cycle, animal, NEm) for (animal, NEm) in animals])
-    NEp = sum([_calculate_NEp(cycle, animal, NEm) for (animal, NEm) in animals])
-    NEg = sum([_calculate_NEg(cycle, animal) for (animal, _NEm) in animals])
+    NEm = sum(non_empty_list([NEm for (animal, NEm) in animals]))
+
+    NEa = non_empty_list([_calculate_NEa(cycle, animal, system, NEm) for (animal, NEm) in animals])
+    NEl = non_empty_list([_calculate_NEl(cycle, animal) for (animal, _NEm) in animals])
+    NEwork = non_empty_list([_calculate_NEwork(cycle, animal, NEm) for (animal, NEm) in animals])
+    NEp = non_empty_list([_calculate_NEp(cycle, animal, NEm) for (animal, NEm) in animals])
+    NEg = non_empty_list([_calculate_NEg(cycle, animal) for (animal, _NEm) in animals])
 
     NEwool = _calculate_NEwool(cycle)
     REM = _calculate_REM(meanDE) if meanDE > 0 else None
@@ -489,50 +514,46 @@ def _calculate_GE(cycle: dict, meanDE: float, system: dict):
 
     NEfeed_m, NEfeed_g = _calculate_NEfeed(cycle)
 
-    logRequirements(cycle, model=MODEL_LOG, term_id=MODEL_KEY,
-                    NEm=NEm,
-                    NEa=NEa,
-                    NEl=NEl,
-                    NEwork=NEwork,
-                    NEp=NEp,
-                    NEg=NEg,
+    logRequirements(cycle, model=MODEL, term=MODEL_KEY,
+                    NEm=_group_logs([(animal.get('term', {}).get('@id'), NEm) for (animal, NEm) in animals]),
+                    NEa=_group_logs(NEa),
+                    NEl=_group_logs(NEl),
+                    NEwork=_group_logs(NEwork),
+                    NEp=_group_logs(NEp),
+                    NEg=_group_logs(NEg),
                     NEwool=NEwool,
                     REM=REM,
                     REG=REG,
                     NEfeed_m=NEfeed_m,
                     NEfeed_g=NEfeed_g)
 
-    return ((NEm + NEa + NEl + NEwork + NEp - NEfeed_m)/REM + (NEg + NEwool - NEfeed_g)/REG) / (meanDE/100) if all([
-        REM, REG
-    ]) else 0
+    return (
+        (NEm + _sum_values(NEa) + _sum_values(NEl) + _sum_values(NEwork) + _sum_values(NEp) - NEfeed_m)/REM +
+        (_sum_values(NEg) + NEwool - NEfeed_g)/REG
+    ) / (meanDE/100) if all([REM, REG]) else 0
 
 
-def _calculate_meanECHHV(cycle: dict, practices: list):
+def _calculate_meanECHHV(practices: list):
     values = list(map(lambda p: _pastureGrass_key_property_value(p, 'energyContentHigherHeatingValue'), practices))
     total_weight = sum([weight/100 for _value, weight in values])
-    meanECHHV = sum([
-        value * weight/100 for value, weight in values
+    return sum([
+        (value * weight/100 if all([value, weight]) else 0) for value, weight in values
     ]) / total_weight if total_weight > 0 else 0
 
-    debugValues(cycle, model=MODEL_LOG, term=MODEL_KEY,
-                meanECHHV=meanECHHV)
-
-    return meanECHHV
-
 
 def _run_practice(cycle: dict, GE: float, meanECHHV: float):
     def run(practice: dict):
         key = practice.get('key', {})
         key_id = key.get('@id')
-        input_term_id = get_lookup_value(key, 'grazedPastureGrassInputId')
+        input_term_id = _practice_input_id(practice)
         value = (GE / meanECHHV) * (list_sum(practice.get('value', [0])) / 100)
 
-        logRequirements(cycle, model=MODEL_LOG, term_id=input_term_id,
+        logRequirements(cycle, model=MODEL, term=input_term_id,
                         GE=GE,
                         meanECHHV=meanECHHV,
                         key_id=key_id)
 
-        logShouldRun(cycle, MODEL_LOG, input_term_id, True)
+        logShouldRun(cycle, MODEL, input_term_id, True)
 
         return _input(input_term_id, value)
 
@@ -545,12 +566,12 @@ def _should_run_practice(cycle: dict):
         key_term_type = practice.get('key', {}).get('termType')
         value = practice.get('value', [])
 
-        logRequirements(cycle, model=MODEL_LOG, term_id=term_id,
-                        value=list_sum(value),
-                        key_term_type=key_term_type)
+        logRequirements(cycle, model=MODEL, term=term_id,
+                        practice_value=list_sum(value),
+                        practice_key_term_type=key_term_type)
 
         should_run = all([len(value) > 0, term_id == MODEL_KEY, key_term_type in KEY_TERM_TYPES])
-        logShouldRun(cycle, MODEL_LOG, term_id, should_run)
+        logShouldRun(cycle, MODEL, term_id, should_run)
         return should_run
 
     return should_run
@@ -558,24 +579,32 @@ def _should_run_practice(cycle: dict):
 
 def _should_run(cycle: dict, practices: dict):
     systems = filter_list_term_type(cycle.get('practices', []), TermTermType.SYSTEM)
-    animalFeed_incomplete = _is_term_type_incomplete(cycle, {'termType': 'animalFeed'})
+    animalFeed_complete = _is_term_type_complete(cycle, {'termType': 'animalFeed'})
+    grazedForage_incomplete = _is_term_type_incomplete(cycle, {'termType': 'grazedForage'})
     all_animals_have_value = all([a.get('value', 0) > 0 for a in cycle.get('animals', [])])
 
-    meanDE = _calculate_meanDE(cycle, practices)
-    meanECHHV = _calculate_meanECHHV(cycle, practices)
+    meanDE = _calculate_meanDE(practices)
+    meanECHHV = _calculate_meanECHHV(practices)
     GE = _calculate_GE(cycle, meanDE, systems[0]) if all([meanDE > 0, len(systems) > 0]) else 0
 
-    logRequirements(cycle, model=MODEL_LOG, term_id=MODEL_KEY,
-                    animalFeed_incomplete=animalFeed_incomplete,
-                    all_animals_have_value=all_animals_have_value,
-                    meanDE=meanDE,
-                    meanECHHV=meanECHHV,
-                    GE=GE)
-
     should_run = all([
-        animalFeed_incomplete, all_animals_have_value, len(systems) > 0, len(practices) > 0, GE > 0, meanECHHV > 0
+        animalFeed_complete, grazedForage_incomplete,
+        all_animals_have_value,
+        len(systems) > 0, len(practices) > 0,
+        GE > 0, meanECHHV > 0
     ])
-    logShouldRun(cycle, MODEL_LOG, MODEL_KEY, should_run)
+
+    for term_id in [MODEL_KEY] + [_practice_input_id(p) for p in practices]:
+        logRequirements(cycle, model=MODEL, term=term_id,
+                        term_type_animalFeed_complete=animalFeed_complete,
+                        term_type_grazedForage_incomplete=grazedForage_incomplete,
+                        all_animals_have_value=all_animals_have_value,
+                        meanDE=meanDE,
+                        meanECHHV=meanECHHV,
+                        GE=GE)
+
+        logShouldRun(cycle, MODEL, term_id, should_run)
+
     return should_run, GE, meanECHHV
 
 
