@@ -1,12 +1,12 @@
 from hestia_earth.models.utils.indicator import _new_indicator
-from hestia_earth.models.utils.pesticideAI import impact_lookup_value
+from hestia_earth.models.utils.pesticideAI import impact_lookup_value, impact_value_set_none
 from . import MODEL
 
 REQUIREMENTS = {
     "ImpactAssessment": {
         "cycle": {
             "@type": "Cycle",
-            "completeness.pesticidesAntibiotics": "True",
+            "completeness.pesticideVeterinaryDrug": "True",
             "inputs": [{"@type": "Input", "value": "", "term.termType": "pesticideAI"}]
         }
     }
@@ -30,4 +30,5 @@ def _indicator(value: float):
 
 def run(impact_assessment: dict):
     value = impact_lookup_value(MODEL, TERM_ID, impact_assessment, LOOKUPS['pesticideAI'])
-    return None if value is None else _indicator(value)
+    should_run = any([value is not None, impact_value_set_none(impact_assessment)])
+    return _indicator(value) if should_run else None
