@@ -3,7 +3,7 @@ from hestia_earth.utils.model import filter_list_term_type, find_term_match, fin
 from hestia_earth.utils.tools import list_sum, safe_parse_float, safe_parse_date
 
 from ..log import logRequirements, debugValues
-from .lookup import _factor_value
+from .lookup import factor_value
 from .term import get_lookup_value
 from .property import get_node_property
 from .product import (
@@ -13,7 +13,7 @@ from .completeness import _is_term_type_complete
 from .blank_node import get_N_total, get_P2O5_total, get_total_value_converted
 from .measurement import most_relevant_measurement_value
 from .site import valid_site_type as site_valid_site_type
-from .crop import is_orchard
+from .crop import is_plantation
 from .currency import DEFAULT_CURRENCY
 
 
@@ -74,7 +74,7 @@ def get_crop_residue_on_field_N_total(cycle: dict) -> float:
         blg_residue_nitrogen(products),
         discarded_residue_on_field_nitrogen_content(products)
     ])
-    return total if _is_term_type_complete(cycle, {'termType': 'cropResidue'}) else 0
+    return total if _is_term_type_complete(cycle, {'termType': TermTermType.CROPRESIDUE.value}) else 0
 
 
 CROP_RESIDUE_DECOMPOSITION_PRODUCT_IDS = [
@@ -112,7 +112,7 @@ def get_excreta_N_total(cycle: dict) -> float:
 
     The result is the sum of every excreta specified in `kg N` as an `Input` or a `Product`.
 
-    Note: in the event where `completeness.products` is set to `True` and there are no excreta inputs or products,
+    Note: in the event where `completeness.product` is set to `True` and there are no excreta inputs or products,
     `0` will be returned.
 
     Parameters
@@ -128,7 +128,7 @@ def get_excreta_N_total(cycle: dict) -> float:
     inputs = filter_list_term_type(cycle.get('inputs', []), TermTermType.EXCRETA)
     products = filter_list_term_type(cycle.get('products', []), TermTermType.EXCRETA)
     values = get_N_total(inputs) + get_N_total(products)
-    return 0 if len(values) == 0 and _is_term_type_complete(cycle, {'termType': 'products'}) else list_sum(values)
+    return 0 if len(values) == 0 and _is_term_type_complete(cycle, {'termType': 'product'}) else list_sum(values)
 
 
 def get_organic_fertiliser_N_total(cycle: dict) -> float:
@@ -251,29 +251,32 @@ def _land_occupation_per_ha(model: str, term_id: str, cycle: dict):
     return value
 
 
-def _orchard_crop_land_occupation_per_ha(model: str, term_id: str, cycle: dict):
+def _plantation_land_occupation_per_ha(model: str, term_id: str, cycle: dict):
     practices = cycle.get('practices', [])
     nurseryDuration = list_sum(find_term_match(practices, 'nurseryDuration').get('value', []), None)
-    orchardBearingDuration = list_sum(find_term_match(practices, 'orchardBearingDuration').get('value', []), None)
-    orchardDensity = list_sum(find_term_match(practices, 'orchardDensity').get('value', []), None)
-    orchardDuration = list_sum(find_term_match(practices, 'orchardDuration').get('value', []), None)
+    plantationProductiveLifespan = list_sum(
+        find_term_match(practices, 'plantationProductiveLifespan').get('value', []), None)
+    plantationDensity = list_sum(find_term_match(practices, 'plantationDensity').get('value', []), None)
+    plantationLifespan = list_sum(find_term_match(practices, 'plantationLifespan').get('value', []), None)
     rotationDuration = list_sum(find_term_match(practices, 'rotationDuration').get('value', []), None)
-    saplings = list_sum(find_term_match(cycle.get('inputs', []), 'saplings').get('value', []), None)
+    nurseryDensity = list_sum(find_term_match(practices, 'nurseryDensity').get('value', []), None)
 
     logRequirements(cycle, model=model, term=term_id,
                     nurseryDuration=nurseryDuration,
-                    saplings=saplings,
-                    orchardDensity=orchardDensity,
-                    orchardDuration=orchardDuration,
-                    orchardBearingDuration=orchardBearingDuration,
+                    nurseryDensity=nurseryDensity,
+                    plantationDensity=plantationDensity,
+                    plantationLifespan=plantationLifespan,
+                    plantationProductiveLifespan=plantationProductiveLifespan,
                     rotationDuration=rotationDuration)
 
     should_run = all([
-        nurseryDuration, saplings, orchardDensity, orchardDuration, orchardBearingDuration, rotationDuration
+        nurseryDuration, nurseryDensity,
+        plantationDensity, plantationLifespan, plantationProductiveLifespan,
+        rotationDuration
     ])
-    return (orchardDuration/orchardBearingDuration) * (
-        1 + (nurseryDuration/365)/saplings * orchardDensity/(orchardDuration/365)  # nursery
-    ) * rotationDuration/orchardDuration if should_run else None
+    return (plantationLifespan/plantationProductiveLifespan) * (
+        1 + (nurseryDuration/365)/nurseryDensity * plantationDensity/(plantationLifespan/365)  # nursery
+    ) * rotationDuration/plantationLifespan if should_run else None
 
 
 def land_occupation_per_ha(model: str, term_id: str, cycle: dict):
@@ -295,8 +298,8 @@ def land_occupation_per_ha(model: str, term_id: str, cycle: dict):
         The land occupation in hectare.
     """
     product = find_primary_product(cycle) or {}
-    orchard_crop = is_orchard(model, product.get('term', {}).get('@id'))
-    return _orchard_crop_land_occupation_per_ha(model, term_id, cycle) if orchard_crop \
+    plantation = is_plantation(model, term_id, product.get('term', {}).get('@id'))
+    return _plantation_land_occupation_per_ha(model, term_id, cycle) if plantation \
         else _land_occupation_per_ha(model, term_id, cycle)
 
 
@@ -454,10 +457,10 @@ def impact_lookup_value(
         The impact total value.
     """
     term_type = blank_nodes[0].get('term', {}).get('termType') if len(blank_nodes) > 0 else None
-    get_factor_value = _factor_value(model, term_id, f"{term_type}.csv", lookup_col)
+    get_factor_value = factor_value(model, term_id, f"{term_type}.csv", lookup_col)
     factors = [(node.get('term', {}).get('@id'), get_factor_value(node)) for node in blank_nodes]
     values = [value for (_term, value) in factors if value is not None]
-    missing_values = [term for (term, value) in factors if value is None]
+    missing_values = set([term for (term, value) in factors if value is None])
     all_nodes_have_value = len(values) == len(factors)
     debugValues({'type': 'Cycle'}, model=model, term=term_id,
                 missing_lookup_factor=';'.join(missing_values),
@@ -483,3 +486,20 @@ def get_ecoClimateZone(cycle: dict) -> int:
     site = cycle.get('site', {})
     measurements = site.get('measurements', [])
     return most_relevant_measurement_value(measurements, 'ecoClimateZone', end_date)
+
+
+def check_cycle_site_ids_identical(cycles: list[dict]) -> bool:
+    """
+    Checks whether the sites of a list of cycles are the same.
+
+    Parameters
+    ----------
+    cycles : list[dict]
+        A list of Hestia `Cycle` nodes, see: https://www.hestia.earth/schema/Cycle.
+
+    Returns
+    -------
+    bool
+        Whether or not all of the cycles associated site ids are identical.
+    """
+    return len(set(cycle.get('site', {}).get('@id', None) for cycle in cycles)) <= 1
