@@ -1,27 +1,56 @@
-from hestia_earth.schema import SchemaType, TermTermType
+from hestia_earth.schema import SchemaType, TermTermType, UNIQUENESS_FIELDS
 from hestia_earth.utils.api import download_hestia
 from hestia_earth.utils.model import filter_list_term_type, find_term_match, linked_node
-from hestia_earth.utils.tools import flatten, list_sum
+from hestia_earth.utils.tools import flatten, list_sum, non_empty_list
 
-from hestia_earth.models.utils.blank_node import get_total_value, get_total_value_converted
-from . import _term_id, _include_model
+from . import _term_id, _include_model, get_dict_key
+from .blank_node import get_total_value, get_total_value_converted
 from .constant import Units
 from .currency import DEFAULT_CURRENCY
-from .property import _get_nitrogen_content, get_node_property
+from .property import _get_nitrogen_content, get_node_property_value
 from .term import get_rice_paddy_terms
 
 
-def _new_product(term, value: float = 0, model=None):
+def _new_product(term, value: float = None, model=None):
     node = {'@type': SchemaType.PRODUCT.value}
     node['term'] = linked_node(term if isinstance(term, dict) else download_hestia(_term_id(term)))
-    node['value'] = [value]
-    if value == 0:
+    if value is not None:
+        node['value'] = [value]
+    elif value == 0:
         node['economicValueShare'] = 0
         node['revenue'] = 0
         node['currency'] = DEFAULT_CURRENCY
     return _include_model(node, model)
 
 
+def _match_list_el(source: list, dest: list, key: str):
+    src_values = non_empty_list([get_dict_key(x, key) for x in source])
+    dest_values = non_empty_list([get_dict_key(x, key) for x in dest])
+    return sorted(src_values) == sorted(dest_values)
+
+
+def _match_el(source: dict, dest: dict, fields: list):
+    def match(key: str):
+        keys = key.split('.')
+        is_list = len(keys) >= 2 and (
+            isinstance(get_dict_key(source, keys[0]), list) or
+            isinstance(get_dict_key(dest, keys[0]), list)
+        )
+        return _match_list_el(
+            get_dict_key(source, keys[0]) or [],
+            get_dict_key(dest, keys[0]) or [],
+            '.'.join(keys[1:])
+        ) if is_list else (get_dict_key(dest, key) is None or get_dict_key(source, key) == get_dict_key(dest, key))
+
+    return all(map(match, fields))
+
+
+def find_by_product(node: dict, product: dict, list_key: str = 'products'):
+    keys = UNIQUENESS_FIELDS.get(node.get('type', node.get('@type')), {}).get(list_key, ['term.@id'])
+    products = node.get(list_key, [])
+    return next((p for p in products if _match_el(p, product, keys)), None)
+
+
 def has_flooded_rice(products: list):
     """
     Checks if one of the product is a flooded rice.
@@ -130,15 +159,20 @@ def discarded_residue_on_field_nitrogen_content(products: list):
     return list_sum(left_on_field + incorporated) * discarded_total_residue_nitrogen_content(products) / 100
 
 
-def animal_produced(products: list, prop: str = 'nitrogenContent') -> float:
+def get_animal_produced_nitrogen(model: str, products: list) -> float:
+    # TODO: refactor this to use `convert_to_nitrogen`
     products = filter_list_term_type(products, [
         TermTermType.LIVEANIMAL, TermTermType.ANIMALPRODUCT, TermTermType.LIVEAQUATICSPECIES
     ])
 
+    def prop_value(input: dict):
+        value = get_node_property_value(model, input, 'nitrogenContent')
+        return value or get_node_property_value(model, input, 'crudeProteinContent', default=0) / 6.25
+
     def product_value(product: dict):
         value = convert_product_to_unit(product, Units.KG_LIVEWEIGHT)
-        property = get_node_property(product, prop)
-        return value * property.get('value', 0) if property else 0
+        property = prop_value(product)
+        return value * property / 100 if all([value, property]) else 0
 
     return list_sum(list(map(product_value, products)))
 
@@ -249,6 +283,10 @@ PRODUCT_UNITS_CONVERSIONS = {
     Units.NUMBER.value: {
         Units.KG_LIVEWEIGHT.value: [
             ('liveweightPerHead', True)
+        ],
+        Units.KG_COLD_CARCASS_WEIGHT.value: [
+            ('liveweightPerHead', True),
+            ('processingConversionLiveweightToColdCarcassWeight', True)
         ]
     }
 }
@@ -258,7 +296,7 @@ def convert_product_to_unit(product: dict, dest_unit: Units):
     from_units = product.get('term', {}).get('units')
     to_units = dest_unit if isinstance(dest_unit, str) else dest_unit.value
     conversions = PRODUCT_UNITS_CONVERSIONS.get(from_units, {}).get(to_units)
-    return 0 if conversions is None else list_sum(
+    return None if len(product.get('value', [])) == 0 else 0 if conversions is None else list_sum(
         flatten([
             get_total_value_converted([product], properties, multiply) for properties, multiply in conversions
         ]) if len(conversions) > 0 else get_total_value([product])
