@@ -8,21 +8,18 @@ class_path = f"hestia_earth.models.{MODEL}.{TERM_ID}"
 fixtures_folder = f"{fixtures_path}/{MODEL}/{TERM_ID}"
 
 
-@patch(f"{class_path}.is_orchard", return_value=False)
-@patch(f"{class_path}.should_download", return_value=True)
-@patch(f"{class_path}.has_geospatial_data")
-def test_should_run(mock_has_geospatial_data, *args):
-    cycle = {'@type': 'Cycle', 'site': {'@type': 'Site'}}
+@patch(f"{class_path}.is_plantation")
+def test_should_run(mock_is_plantation):
+    cycle = {'@type': 'Cycle'}
 
-    mock_has_geospatial_data.return_value = True
+    mock_is_plantation.return_value = False
     assert _should_run(cycle) is True
 
-    mock_has_geospatial_data.return_value = False
+    mock_is_plantation.return_value = True
     assert not _should_run(cycle)
 
 
 @patch(f"{class_path}._new_practice", side_effect=fake_new_practice)
-@patch(f"{class_path}.download", return_value=10)
 def test_run(*args):
     with open(f"{fixtures_folder}/cycle.jsonld", encoding='utf-8') as f:
         cycle = json.load(f)
